toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final sha1Hex = _sha1
      .map((b) => b.toRadixString(16).padLeft(2, '0').toUpperCase())
      .join(':');
  return 'X509Certificate(\n'
      '  Subject:        $_subject\n'
      '  Issuer:         $_issuer\n'
      '  SHA-1:          $sha1Hex\n'
      '  Valid from:     $_startValidity\n'
      '  Valid until:    $_endValidity\n'
      ')';
}